================================================
PyFOL(Python function optimization Library)
================================================

Describe:
============================================
Optimize Python functions to give users more *convenient* and *efficient* use of various functions

NowVersion:
============================================
1.1.6.1(*Fixed some known problems*)

Existing functions:
============================================
* String(Class)
    + setstr
    + clearstr
    + split
    + replace
    + find
    + append
    + insert
    + add
    + delete
    + pop
    + count
    + reverse
    + chartotal
    
* LinkedList(Class(DataStructure))
    + isempty
    + length
    + append
    + insert
    + add
    + remove
    + delete
    + isexist
    + setvalue
    + search
    + show
    
* Digit(Class)
    + plus
    + minus
    + multiply
    + divide
    + mod
    + sum
    + pow(int,int)
    + fac(int)

* Queue(Class(DataStructure)):
    + isempty
    + isfull
    + length
    + put
    + leave
    + show

* Stack(Class(DataStructure)):
    + isempty
    + height
    + push
    + pop
    + show

* Data(Class):
    + swap
    + max
    + min
    + maxlst
    + minlst
    + avg
    + gcd
    + lcm
    + randms

* Help(Class):
    + StringHelp(Setstr,Clearstr...)

Installation instructions:
============================================
Code support version >=3.7
(*If you can't download the latest version, please upgrade your Python to about version 3.8*)

Download method: 
============================================
pip(3) install PyFOL
Reference through import pyfol

LICENSE
============================================
See license for *copyright documents*
